@@ -5,20 +5,14 @@ package cgmgr
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"strconv"
 	"strings"
 
-	"github.com/containers/podman/v3/pkg/rootless"
 	"github.com/cri-o/cri-o/internal/config/node"
 	libctr "github.com/opencontainers/runc/libcontainer/cgroups"
-	"github.com/opencontainers/runc/libcontainer/cgroups/fs"
-	"github.com/opencontainers/runc/libcontainer/cgroups/fs2"
-	cgcfgs "github.com/opencontainers/runc/libcontainer/configs"
 	rspec "github.com/opencontainers/runtime-spec/specs-go"
-	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
 	types "k8s.io/cri-api/pkg/apis/runtime/v1"
 )
@@ -78,9 +72,6 @@ type CgroupManager interface {
 	// CreateSandboxCgroup takes the sandbox parent, and sandbox ID.
 	// It creates a new cgroup for that sandbox, which is useful when spoofing an infra container.
 	CreateSandboxCgroup(sbParent, containerID string) error
-	// RemoveSandboxCgroup takes the sandbox parent, and sandbox ID.
-	// It removes the cgroup for that sandbox, which is useful when spoofing an infra container.
-	RemoveSandboxCgroup(sbParent, containerID string) error
 }
 
 // New creates a new CgroupManager with defaults
@@ -109,19 +100,19 @@ func SetCgroupManager(cgroupManager string) (CgroupManager, error) {
 		}
 		return &cgroupfsMgr, nil
 	default:
-		return nil, errors.Errorf("invalid cgroup manager: %s", cgroupManager)
+		return nil, fmt.Errorf("invalid cgroup manager: %s", cgroupManager)
 	}
 }
 
 func verifyCgroupHasEnoughMemory(slicePath, memorySubsystemPath, memoryMaxFilename string) error {
 	// read in the memory limit from memory max file
-	fileData, err := ioutil.ReadFile(filepath.Join(memorySubsystemPath, slicePath, memoryMaxFilename))
+	fileData, err := os.ReadFile(filepath.Join(memorySubsystemPath, slicePath, memoryMaxFilename))
 	if err != nil {
 		if os.IsNotExist(err) {
 			logrus.Warnf("Failed to find %s at path: %q", memoryMaxFilename, slicePath)
 			return nil
 		}
-		return errors.Wrapf(err, "unable to read memory file for cgroups at %s", slicePath)
+		return fmt.Errorf("unable to read memory file for cgroups at %s: %w", slicePath, err)
 	}
 
 	// strip off the newline character and convert it to an int
@@ -129,11 +120,11 @@ func verifyCgroupHasEnoughMemory(slicePath, memorySubsystemPath, memoryMaxFilena
 	if strMemory != "" && strMemory != "max" {
 		memoryLimit, err := strconv.ParseInt(strMemory, 10, 64)
 		if err != nil {
-			return errors.Wrapf(err, "error converting cgroup memory value from string to int %q", strMemory)
+			return fmt.Errorf("error converting cgroup memory value from string to int %q: %w", strMemory, err)
 		}
 		// Compare with the minimum allowed memory limit
 		if err := VerifyMemoryIsEnough(memoryLimit); err != nil {
-			return errors.Errorf("pod %v", err)
+			return fmt.Errorf("pod %w", err)
 		}
 	}
 	return nil
@@ -168,39 +159,3 @@ func MoveProcessToContainerCgroup(containerPid, commandPid int) error {
 	}
 	return nil
 }
-
-// createSandboxCgroup takes the path of the sandbox parent and the desired containerCgroup
-// It creates a cgroup through cgroupfs (as opposed to systemd) at the location cgroupRoot/sbParent/containerCgroup.
-func createSandboxCgroup(sbParent, containerCgroup string) error {
-	mgr, err := libctrCgroupManager(sbParent, containerCgroup)
-	if err != nil {
-		return err
-	}
-	return mgr.Apply(-1)
-}
-
-func removeSandboxCgroup(sbParent, containerCgroup string) error {
-	mgr, err := libctrCgroupManager(sbParent, containerCgroup)
-	if err != nil {
-		return err
-	}
-	return mgr.Destroy()
-}
-
-func libctrCgroupManager(sbParent, containerCgroup string) (libctr.Manager, error) {
-	cg := &cgcfgs.Cgroup{
-		Name:   containerCgroup,
-		Parent: sbParent,
-		Resources: &cgcfgs.Resources{
-			SkipDevices: true,
-		},
-	}
-	if node.CgroupIsV2() {
-		return fs2.NewManager(cg, "", rootless.IsRootless())
-	}
-	return fs.NewManager(cg, nil, rootless.IsRootless()), nil
-}
-
-func containerCgroupPath(id string) string {
-	return crioPrefix + "-" + id
-}
