@@ -1,15 +1,16 @@
 package server
 
 import (
-	"github.com/pkg/errors"
+	"errors"
+
 	"golang.org/x/net/context"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
-	pb "k8s.io/cri-api/pkg/apis/runtime/v1alpha2"
+	types "k8s.io/cri-api/pkg/apis/runtime/v1"
 )
 
 // ExecSync runs a command in a container synchronously.
-func (s *Server) ExecSync(ctx context.Context, req *pb.ExecSyncRequest) (*pb.ExecSyncResponse, error) {
+func (s *Server) ExecSync(ctx context.Context, req *types.ExecSyncRequest) (*types.ExecSyncResponse, error) {
 	c, err := s.GetContainerFromShortID(req.ContainerId)
 	if err != nil {
 		return nil, status.Errorf(codes.NotFound, "could not find container %q: %v", req.ContainerId, err)
@@ -24,13 +25,5 @@ func (s *Server) ExecSync(ctx context.Context, req *pb.ExecSyncRequest) (*pb.Exe
 		return nil, errors.New("exec command cannot be empty")
 	}
 
-	execResp, err := s.Runtime().ExecSyncContainer(ctx, c, cmd, req.Timeout)
-	if err != nil {
-		return nil, err
-	}
-	return &pb.ExecSyncResponse{
-		Stdout:   execResp.Stdout,
-		Stderr:   execResp.Stderr,
-		ExitCode: execResp.ExitCode,
-	}, nil
+	return s.Runtime().ExecSyncContainer(ctx, c, cmd, req.Timeout)
 }
