@@ -6,8 +6,11 @@ import (
 	pb "k8s.io/cri-api/pkg/apis/runtime/v1"
 )
 
-func (c *service) RemoveContainer(
+func (s *service) RemoveContainer(
 	ctx context.Context, req *pb.RemoveContainerRequest,
 ) (*pb.RemoveContainerResponse, error) {
-	return nil, nil
+	if err := s.server.RemoveContainer(ctx, req); err != nil {
+		return nil, err
+	}
+	return &pb.RemoveContainerResponse{}, nil
 }
