@@ -6,8 +6,11 @@ import (
 	pb "k8s.io/cri-api/pkg/apis/runtime/v1"
 )
 
-func (c *service) RemovePodSandbox(
+func (s *service) RemovePodSandbox(
 	ctx context.Context, req *pb.RemovePodSandboxRequest,
 ) (*pb.RemovePodSandboxResponse, error) {
-	return nil, nil
+	if err := s.server.RemovePodSandbox(ctx, req); err != nil {
+		return nil, err
+	}
+	return &pb.RemovePodSandboxResponse{}, nil
 }
